"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StorageS3 = void 0;
const config_1 = require("../config");
const backend_1 = require("./backend");
const S3Ctor = require('aws-sdk/clients/s3');
class StorageS3 extends backend_1.StorageBackend {
    constructor(name, options) {
        config_1.log.verbose('StorageS3', 'constructor()');
        options.type = 's3';
        super(name, options);
        options = options;
        this.s3 = new S3Ctor({
            credentials: {
                accessKeyId: options.accessKeyId,
                secretAccessKey: options.secretAccessKey,
            },
            region: options.region,
        });
    }
    toString() {
        const text = [
            this.constructor.name,
            '<',
            this.name,
            '>',
        ].join('');
        return text;
    }
    async save(payload) {
        config_1.log.verbose('StorageS3', 'save()');
        const options = this.options;
        await this.s3.putObject({
            Body: JSON.stringify(payload),
            Bucket: options.bucket,
            Key: this.name,
        }).promise();
    }
    async load() {
        config_1.log.verbose('StorageS3', 'load()');
        const options = this.options;
        try {
            const result = await this.s3.getObject({
                Bucket: options.bucket,
                Key: this.name,
            }).promise();
            if (!result || !result.Body) {
                return {};
            }
            return JSON.parse(result.Body.toString());
        }
        catch (e) {
            if (/^4/.test(e.statusCode)) {
                return {};
            }
            throw e;
        }
    }
    async destroy() {
        config_1.log.verbose('StorageS3', 'destroy()');
        const options = this.options;
        await this.s3.deleteObject({
            Bucket: options.bucket,
            Key: this.name,
        }).promise();
    }
}
exports.StorageS3 = StorageS3;
exports.default = StorageS3;
//# sourceMappingURL=s3.js.map